<?php

namespace Drupal\python_env\Service;

use Symfony\Component\Process\Process;
use Symfony\Component\DependencyInjection\ContainerInterface;

class PythonBridge {

  protected $pythonPath;
  protected $scriptsDir;

  public function __construct(ContainerInterface $container) {
    $this->pythonPath = 'python3';  // Adjust if needed
    $this->scriptsDir = DRUPAL_ROOT . '/../python/'; // Root-level /python/ directory
  }

  /**
   * Runs a Python script with arguments.
   *
   * @param string $scriptName
   *   The name of the script (without .py extension).
   * @param array $args
   *   Key-value args passed to the script.
   *
   * @return array
   *   The JSON-decoded result.
   *
   * @throws \Exception
   *   On missing file or script error.
   */
  public function run(string $scriptName, array $args = []): array {
    $scriptFile = $this->scriptsDir . $scriptName . '.py';

    if (!file_exists($scriptFile)) {
      throw new \Exception("Python script not found: $scriptFile");
    }

    $inputJson = json_encode($args);
    $cmd = [$this->pythonPath, $scriptFile, $inputJson];

    $process = new Process($cmd);
    $process->run();

    if (!$process->isSuccessful()) {
      throw new \Exception("Python error: " . $process->getErrorOutput());
    }

    return json_decode($process->getOutput(), true);
  }
}
